home | help
GMX-INSERT-MOLECULES(1) 	     GROMACS		 GMX-INSERT-MOLECULES(1)

NAME
     gmx-insert-molecules - Insert molecules into existing vacancies

SYNOPSIS
	gmx insert-molecules [-f [<.gro/.g96/...>]] [-ci [<.gro/.g96/...>]]
		     [-ip [<.dat>]] [-n [<.ndx>]] [-o [<.gro/.g96/...>]]
		     [-replace <selection>] [-sf <file>] [-selrpos <enum>]
		     [-box <vector>] [-nmol <int>] [-conc <real>]
		     [-try <int>] [-seed <int>] [-radius <real>]
		     [-scale <real>] [-dr <vector>] [-rot <enum>]

DESCRIPTION
     gmx  insert-molecules  inserts  -nmol copies of the system specified in the
     -ci input file. The number of copies can also be determined by the  concen-
     tration  -conc  in mol/liter and box volume.  The insertions take place ei-
     ther into vacant space in the solute conformation given with -f, or into an
     empty box given by -box.  Specifying both -f and -box behaves like -f,  but
     places  a	new  box  around  the  solute before insertions.  Any velocities
     present are discarded.

     It is possible to also insert into a  solvated  configuration  and  replace
     solvent  atoms with the inserted atoms. To do this, use -replace to specify
     a selection that identifies the atoms that can be replaced.  The  tool  as-
     sumes that all molecules in this selection consist of single residues: each
     residue  from this selection that overlaps with the inserted molecules will
     be removed instead of preventing insertion.

     By default, the insertion positions are random (with initial seed specified
     by -seed). The program iterates until -nmol molecules have been inserted in
     the box. Molecules are not inserted where the distance between any existing
     atom and any atom of the inserted molecule is less than the  sum  based  on
     the van der Waals radii of both atoms. A database (vdwradii.dat) of van der
     Waals  radii  is  read  by  the  program, and the resulting radii scaled by
     -scale. If radii are not found in the database, those  atoms  are	assigned
     the (pre-scaled) distance -radius.  Note that the usefulness of those radii
     depends on the atom names, and thus varies widely with force field.

     A	total  of -nmol * -try insertion attempts are made before giving up. In-
     crease -try if you have several small holes to fill. Option -rot  specifies
     whether  the insertion molecules are randomly oriented before insertion at-
     tempts.

     Alternatively, the molecules can be inserted only at positions  defined  in
     positions.dat (-ip). That file should have 3 columns (x,y,z), that give the
     displacements compared to the input molecule position (-ci). Hence, if that
     file  should  contain the absolute positions, the molecule must be centered
     on (0,0,0) before using gmx insert-molecules (e.g. from gmx editconf  -cen-
     ter).   Comments  in  that file starting with # are ignored. Option -dr de-
     fines the maximally allowed displacements during  insertial  trials.   -try
     and -rot work as in the default mode (see above).

OPTIONS
     Options to specify input files:

     -f [<.gro/.g96/...>] (protein.gro) (Optional)
	    Existing configuration to insert into: gro g96 pdb brk ent esp tpr

     -ci [<.gro/.g96/...>] (insert.gro)
	    Configuration to insert: gro g96 pdb brk ent esp tpr

     -ip [<.dat>] (positions.dat) (Optional)
	    Predefined insertion trial positions

     -n [<.ndx>] (index.ndx) (Optional)
	    Extra index groups

     Options to specify output files:

     -o [<.gro/.g96/...>] (out.gro)
	    Output configuration after insertion: gro g96 pdb brk ent esp

     Other options:

     -replace <selection>
	    Atoms that can be removed if overlapping

     -sf <file>
	    Provide selections from files

     -selrpos <enum> (atom)
	    Selection  reference  positions:  atom,  res_com,  res_cog, mol_com,
	    mol_cog, whole_res_com, whole_res_cog, whole_mol_com, whole_mol_cog,
	    part_res_com, part_res_cog, part_mol_com, part_mol_cog, dyn_res_com,
	    dyn_res_cog, dyn_mol_com, dyn_mol_cog

     -box <vector> (0 0 0)
	    Box size (in nm)

     -nmol <int> (0)
	    Number of extra molecules to insert

     -conc <real> (0)
	    Concentration (in mol/liter) of  extra  molecules  to  insert.  This
	    overrides -nmol

     -try <int> (10)
	    Try inserting -nmol times -try times

     -seed <int> (0)
	    Random generator seed (0 means generate)

     -radius <real> (0.105)
	    Default van der Waals distance

     -scale <real> (0.57)
	    Scale  factor  to  multiply Van der Waals radii from the database in
	    share/gromacs/top/vdwradii.dat. The default  value	of  0.57  yields
	    density close to 1000 g/l for proteins in water.

     -dr <vector> (0 0 0)
	    Allowed displacement in x/y/z from positions in -ip file

     -rot <enum> (xyz)
	    Rotate inserted molecules randomly: xyz, z, none

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026		 GMX-INSERT-MOLECULES(1)

home | help